==> plugin-android-0.0.1-sources.jar: com/zoyi/channel/plugin/android/view/layout/LinkedTextView.java <==
package com.zoyi.channel.plugin.android.view.layout;

import android.content.Context;
import android.support.annotation.NonNull;
import android.support.v4.content.ContextCompat;
import android.text.Spannable;
import android.text.SpannableString;
import android.text.TextPaint;
import android.text.method.LinkMovementMethod;
import android.text.style.ClickableSpan;
import android.util.AttributeSet;
import android.view.View;
import android.widget.TextView;
import com.zoyi.channel.plugin.android.R;
import com.zoyi.channel.plugin.android.util.L;
import com.zoyi.channel.plugin.android.util.Patterns;
import com.zoyi.channel.plugin.android.view.handler.TextLinkClickListener;

import java.util.ArrayList;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;


public class LinkedTextView extends TextView {
  private List<Hyperlink> listOfLinks;
  TextLinkClickListener listener;
  Pattern urlPattern = Pattern.compile("(?<=\\s|^)(https?|ftp|file)://\\S*");

  public LinkedTextView(Context context) {
    super(context);
    init();
  }

  public LinkedTextView(Context context, AttributeSet attrs) {
    super(context, attrs);
    init();
  }

  private void init() {
    listOfLinks = new ArrayList<>();
    setMovementMethod(LinkMovementMethod.getInstance());
  }

  public void setLinkedText(String text) {
    listOfLinks.clear();
    SpannableString linkableText = new SpannableString(text);
    gatherLinks(listOfLinks, linkableText, urlPattern);

    for (Hyperlink listOfLink : listOfLinks) {
      try {
        linkableText.setSpan(
            listOfLink.span,
            listOfLink.start,
            listOfLink.end,
            Spannable.SPAN_EXCLUSIVE_EXCLUSIVE);
      } catch (Exception ex) {
      }
    }

    setText(linkableText);
  }

  public void setOnTextLinkClickListener(TextLinkClickListener listener) {
    this.listener = listener;
  }

  private void gatherLinks(
      List<Hyperlink> links,
      Spannable s,
      Pattern pattern) {
    Matcher m = Patterns.WEB_URL.matcher(s);

    while (m.find()) {
      int start = m.start();
      int end = m.end();

      Hyperlink spec = new Hyperlink();
      spec.span = new InternalURLSpan(getContext(), s.subSequence(start, end).toString());
      spec.start = start;
      spec.end = end;

      links.add(spec);
    }
  }

  private class InternalURLSpan extends ClickableSpan {
    private Context context;
    private String string;

    InternalURLSpan(Context context, String string) {
      this.context = context;
      this.string = string;
    }

    @Override
    public void onClick(View textView) {
      if (listener != null && string != null) {
        listener.onTextLinkClick(textView, string.trim());
      }
    }

    @Override
    public void updateDrawState(@NonNull TextPaint textPaint) {
      try {
        textPaint.setColor(ContextCompat.getColor(context, R.color.cobalt));
        textPaint.setUnderlineText(false);
      } catch (Exception ignored) { }
    }
  }

  private class Hyperlink {
    CharSequence textSpan;
    InternalURLSpan span;
    int start;
    int end;
  }
}

==> plugin-android-0.0.6-sources.jar: com/zoyi/channel/plugin/android/view/layout/LinkedTextView.java <==
package com.zoyi.channel.plugin.android.view.layout;

import android.content.Context;
import android.support.annotation.NonNull;
import android.support.v4.content.ContextCompat;
import android.text.Spannable;
import android.text.SpannableString;
import android.text.TextPaint;
import android.text.method.LinkMovementMethod;
import android.text.style.ClickableSpan;
import android.util.AttributeSet;
import android.view.View;
import android.widget.TextView;
import com.zoyi.channel.plugin.android.R;
import com.zoyi.channel.plugin.android.util.L;
import com.zoyi.channel.plugin.android.util.Patterns;
import com.zoyi.channel.plugin.android.view.handler.TextLinkClickListener;

import java.util.ArrayList;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;


public class LinkedTextView extends TextView {
  private List<Hyperlink> listOfLinks;
  TextLinkClickListener listener;
  Pattern urlPattern = Pattern.compile("(?<=\\s|^)(https?|ftp|file)://\\S*");

  public LinkedTextView(Context context) {
    super(context);
    init();
  }

  public LinkedTextView(Context context, AttributeSet attrs) {
    super(context, attrs);
    init();
  }

  private void init() {
    listOfLinks = new ArrayList<>();
    setMovementMethod(LinkMovementMethod.getInstance());
  }

  public void setLinkedText(String text) {
    listOfLinks.clear();
    SpannableString linkableText = new SpannableString(text);
    gatherLinks(listOfLinks, linkableText, urlPattern);

    for (Hyperlink listOfLink : listOfLinks) {
      try {
        linkableText.setSpan(
            listOfLink.span,
            listOfLink.start,
            listOfLink.end,
            Spannable.SPAN_EXCLUSIVE_EXCLUSIVE);
      } catch (Exception ex) {
      }
    }

    setText(linkableText);
  }

  public void setOnTextLinkClickListener(TextLinkClickListener listener) {
    this.listener = listener;
  }

  private void gatherLinks(
      List<Hyperlink> links,
      Spannable s,
      Pattern pattern) {
    Matcher m = Patterns.WEB_URL.matcher(s);

    while (m.find()) {
      int start = m.start();
      int end = m.end();

      Hyperlink spec = new Hyperlink();
      spec.span = new InternalURLSpan(getContext(), s.subSequence(start, end).toString());
      spec.start = start;
      spec.end = end;

      links.add(spec);
    }
  }

  private class InternalURLSpan extends ClickableSpan {
    private Context context;
    private String string;

    InternalURLSpan(Context context, String string) {
      this.context = context;
      this.string = string;
    }

    @Override
    public void onClick(View textView) {
      if (listener != null && string != null) {
        listener.onTextLinkClick(textView, string.trim());
      }
    }

    @Override
    public void updateDrawState(@NonNull TextPaint textPaint) {
      try {
        textPaint.setColor(ContextCompat.getColor(context, R.color.ch_cobalt));
        textPaint.setUnderlineText(false);
      } catch (Exception ignored) { }
    }
  }

  private class Hyperlink {
    CharSequence textSpan;
    InternalURLSpan span;
    int start;
    int end;
  }
}
